@@ -48,13 +48,17 @@ class GSPeerConnectionBroadcasterPiCaller:
 
     async def startSocket(self):
         self._logger.debug("start broadcast socket")
-        await GSPeerConnectionBroadcasterPiSocketv2.create(self.sio, self.gsdbs, self.camera, self.oncommand, self.setChannel)
+        await GSPeerConnectionBroadcasterPiSocketv2.create(self.sio, self.gsdbs, self.camera, self.oncommand,
+                                                           self.setChannel)
 
     def getconnectionurl(self):
         connectURL = self.gsdbs.credentials["signalserver"]
 
         return f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}'
 
+    async def disconnectClient(self):
+        await self.sio.disconnect()
+
 
 class GSPeerConnectionBroadcasterPiSocket:
 
